@@ -60,6 +60,7 @@ test_that("Require two or more exposures", {
 # lfe package - modified example from condfstat() helpfile
 
 test_that("Check approx. equivalence with lfe package", {
+  skip_if_not_installed("lfe")
   library(lfe)
   set.seed(12345)
   n <- 4000
@@ -94,6 +95,8 @@ test_that("Check approx. equivalence with lfe package", {
 # Stata ivreg2 example
 
 test_that("Compare with Stata ivreg2 output", {
+  skip_if_not_installed("haven")
+  skip_if_not_installed("lfe")
   library(haven)
   library(ivreg)
   library(lfe)
